/*
     This file is part of GNUnet.
     (C) 2001, 2002, 2003 Christian Grothoff (and other contributing authors)

     GNUnet is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2, or (at your
     option) any later version.

     GNUnet is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with GNUnet; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
*/

/**
 * @file applications/afs/tools/gnunet-pseudonym-delete.c
 * @brief delete a pseudoynm
 * @author Christian Grothoff
 **/

#include "gnunet_afs_esed2.h"

static char * pname = NULL;

/**
 * Perform option parsing from the command line. 
 **/
static int parser(int argc, 
	   char * argv[]) {
  int cont = OK;
  int c;

  FREENONNULL(setConfigurationString("GNUNETD",
				     "LOGFILE",
				     NULL));
  while (1) {
    int option_index = 0;
    static struct GNoption long_options[] = {
      { "loglevel", 1, 0, 'L' },
      { "config",   1, 0, 'c' },
      { "version",  0, 0, 'v' },
      { "help",     0, 0, 'h' },
      { 0,0,0,0 }
    };
    
    c = GNgetopt_long(argc,
		      argv, 
		      "vhc:L:", 
		      long_options, 
		      &option_index);
    
    if (c == -1) 
      break;  /* No more flags to process */
    
    switch(c) {
    case 'c':
      FREENONNULL(setConfigurationString("FILES",
					 "gnunet.conf",
					 GNoptarg));
      break;
    case 'v': 
      printf("gnunet-pseudoynm-delete v%s\n",
	     VERSION);
      cont = SYSERR;
      break;
    case 'h': 
      printf("USAGE: gnunet-pseudonym-delete [OPTIONS] PSEUDONYM\n"\
	     "-h, --help                    : "
	     "print this page\n"
	     "-c FILENAME, --config=FILENAME: "
	     "load config file (defaults: %s)\n"
	     "-v, --version                 : "
	     "print the version number\n"\
	     "-L LOGLEVEL, --loglevel=LOGL  : "
	     "set the loglevel\n",
	     DEFAULT_CONFIG_FILE);
      cont = SYSERR;
      break;
    case 'L':
      FREENONNULL(setConfigurationString("GNUNETD",
					 "LOGLEVEL",
					 GNoptarg));
      break;
    default:
      LOG(LOG_FAILURE, 
	  "FAILURE: Unknown option %c. Aborting.\n"\
	  "Use --help to get a list of options.\n",
	  c);
      cont = SYSERR;    
    } /* end of parsing commandline */
  }
  if (GNoptind < argc)
    pname = argv[GNoptind++];
  if (GNoptind < argc) {
    LOG(LOG_WARNING, 
	"WARNING: Invalid arguments: ");
    while (GNoptind < argc)
      LOG(LOG_WARNING, 
	  "%s ", argv[GNoptind++]);
    LOG(LOG_FATAL,
	"FATAL: Invalid arguments. Exiting.\n");
    return SYSERR;
  }
  return cont;
}


int main(int argc, char *argv[]) {
  if (OK != initUtil(argc, argv, &parser))
    return SYSERR;
  if (pname == NULL) {
    printf("You must specify a name for the pseudonym.\n");
    doneUtil();
    return SYSERR;    
  }

  if (OK == deletePseudonym(pname))
    printf("Pseudonym %s deleted.\n",
	   pname);
  else
    printf("Error deleting pseudonym %s (does not exist?).\n",
	   pname);

  doneUtil();
  return 0;
}


/* end of gnunet-pseudonym-delete.c */
